@@ -23,18 +23,17 @@
 
 #ifdef HAVE_GSSAPI
 
-#include <c-strcase.h>
-#include <c-ctype.h>
+#include <ctype.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
 
 static char *find_space(char *str)
 {
-	while(*str != 0 && c_isspace(*str) == 0) {
+	while (*str != 0 && isspace(*str) == 0) {
 		str++;
 	}
-	if (c_isspace(*str))
+	if (isspace(*str))
 		return str;
 	return NULL;
 }
@@ -52,7 +51,7 @@ void parse_kkdcp_string(char *str, int *socktype, char **_port, char **_server,
 
 	*realm = 0;
 	realm++;
-	while (c_isspace(*realm))
+	while (isspace(*realm))
 		realm++;
 
 	server = find_space(realm);
@@ -65,7 +64,7 @@ void parse_kkdcp_string(char *str, int *socktype, char **_port, char **_server,
 	*server = 0;
 	server++;
 
-	while (c_isspace(*server))
+	while (isspace(*server))
 		server++;
 
 	if (strncmp(server, "udp@", 4) == 0) {
@@ -102,8 +101,6 @@ void parse_kkdcp_string(char *str, int *socktype, char **_port, char **_server,
 	*_realm = realm;
 	*_path = path;
 	*_server = server;
-
-	return;
 }
 
 #endif
