@@ -211,7 +211,7 @@ static void check_for_duplicate_password_auth(struct perm_cfg_st *config, const
 
 static void figure_auth_funcs(void *pool, const char *vhostname,
 			      struct perm_cfg_st *config, char **auth, unsigned auth_size,
-			      unsigned primary)
+			      unsigned primary, unsigned is_worker)
 {
 	unsigned j, i;
 	unsigned found;
@@ -260,7 +260,9 @@ static void figure_auth_funcs(void *pool, const char *vhostname,
 			}
 			talloc_free(auth[j]);
 		}
-		fprintf(stderr, NOTESTR"%s: setting '%s' as primary authentication method\n", vhostname, config->auth[0].name);
+
+		if (!is_worker)
+			fprintf(stderr, NOTESTR"%s: setting '%s' as primary authentication method\n", vhostname, config->auth[0].name);
 	} else {
 		unsigned x = config->auth_methods;
 		/* Append authentication methods (alternative options) */
@@ -272,7 +274,8 @@ static void figure_auth_funcs(void *pool, const char *vhostname,
 						config->auth[x].additional = avail_auth_types[i].get_brackets_string(pool, config, auth[j]+avail_auth_types[i].name_size);
 
 					config->auth[x].name = talloc_strdup(pool, avail_auth_types[i].name);
-					fprintf(stderr, NOTESTR"%s: enabling '%s' as authentication method\n", vhostname, avail_auth_types[i].name);
+					if (!is_worker)
+						fprintf(stderr, NOTESTR"%s: enabling '%s' as authentication method\n", vhostname, avail_auth_types[i].name);
 
 					check_for_duplicate_password_auth(config, vhostname, avail_auth_types[i].type);
 					config->auth[x].amod = avail_auth_types[i].mod;
@@ -316,7 +319,8 @@ static acct_types_st avail_acct_types[] =
 #endif
 };
 
-static void figure_acct_funcs(void *pool, const char *vhostname, struct perm_cfg_st *config, const char *acct)
+static void figure_acct_funcs(void *pool, const char *vhostname, struct perm_cfg_st *config,
+			      const char *acct, unsigned is_worker)
 {
 	unsigned i;
 	unsigned found = 0;
@@ -349,7 +353,9 @@ static void figure_acct_funcs(void *pool, const char *vhostname, struct perm_cfg
 		fprintf(stderr, ERRSTR"%s: unknown or unsupported accounting method: %s\n", vhostname, acct);
 		exit(EXIT_FAILURE);
 	}
-	fprintf(stderr, NOTESTR"%ssetting '%s' as accounting method\n", vhostname, config->acct.name);
+
+	if (!is_worker)
+		fprintf(stderr, NOTESTR"%ssetting '%s' as accounting method\n", vhostname, config->acct.name);
 }
 
 #ifdef HAVE_GSSAPI
@@ -523,6 +529,7 @@ static void apply_default_conf(vhost_cfg_st *vhost, unsigned reload)
 	if (!reload) { /* perm config defaults */
 		tls_vhost_init(vhost);
 		vhost->perm_config.stats_reset_time = 24*60*60*7; /* weekly */
+		vhost->perm_config.log_level = DEFAULT_LOG_LEVEL;
 	}
 
 	vhost->perm_config.config->mobile_idle_timeout = (unsigned)-1;
@@ -594,6 +601,7 @@ static vhost_cfg_st *vhost_add(void *pool, struct list_head *head, const char *n
 struct ini_ctx_st {
 	struct list_head *head;
 	unsigned reload;
+	unsigned is_worker;
 	const char *file;
 	void *pool;
 };
@@ -688,6 +696,7 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 	struct cfg_st *config;
 	void *pool;
 	unsigned reload = ctx->reload;
+	unsigned is_worker = ctx->is_worker;
 	int ret;
 	unsigned stage1_found = 1;
 	unsigned force_cert_auth;
@@ -704,7 +713,7 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 		char *vname;
 
 		if (strncmp(section, "vhost:", 6) != 0) {
-			if (reload == 0)
+			if (reload == 0 && is_worker == 0)
 				fprintf(stderr, WARNSTR"skipping unknown section '%s'\n", section);
 			return 1;
 		}
@@ -726,13 +735,15 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 		}
 
 		if (strcasecmp(section+6, vname) != 0) {
-			fprintf(stderr, NOTESTR"virtual host name '%s' was canonicalized to '%s'\n",
-				section+6, vname);
+			if (reload == 0 && is_worker == 0)
+				fprintf(stderr, NOTESTR"virtual host name '%s' was canonicalized to '%s'\n",
+					section+6, vname);
 		}
 
 		if (!found_vhost) {
 			/* add */
-			fprintf(stderr, NOTESTR"adding virtual host: %s\n", vname);
+			if (reload == 0 && is_worker == 0)
+				fprintf(stderr, NOTESTR"adding virtual host: %s\n", vname);
 			vhost = vhost_add(ctx->pool, ctx->head, vname, reload);
 		}
 		talloc_free(vname);
@@ -822,15 +833,14 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 		} else if (strcmp(name, "pid-file") == 0) {
 			if (pid_file[0] == 0) {
 				READ_STATIC_STRING(pid_file);
-			} else if (reload == 0)
+			} else if (reload == 0 && !ctx->is_worker)
 				fprintf(stderr, NOTESTR"skipping 'pid-file' config option\n");
 		} else if (strcmp(name, "sec-mod-scale") == 0) {
 			if (!PWARN_ON_VHOST(vhost->name, "sec-mod-scale", sec_mod_scale))
 				READ_NUMERIC(vhost->perm_config.sec_mod_scale);
 		} else if (strcmp(name, "log-level") == 0) {
-			if (vhost->perm_config.debug == 0) {
-				READ_NUMERIC(vhost->perm_config.debug);
-			}
+			READ_NUMERIC(vhost->perm_config.log_level);
+			global_log_prio = vhost->perm_config.log_level;
 		} else {
 			stage1_found = 0;
 		}
@@ -1182,6 +1192,7 @@ static void parse_cfg_file(void *pool, const char *file, struct list_head *head,
 	memset(&ctx, 0, sizeof(ctx));
 	ctx.file = file;
 	ctx.reload = (flags&CFG_FLAG_RELOAD)?1:0;
+	ctx.is_worker = (flags&CFG_FLAG_WORKER)?1:0;
 	ctx.head = head;
 
 #if defined(PROC_FS_SUPPORTED)
@@ -1282,10 +1293,13 @@ static void parse_cfg_file(void *pool, const char *file, struct list_head *head,
 				exit(EXIT_FAILURE);
 			}
 
-			figure_auth_funcs(vhost, PREFIX_VHOST(vhost), &vhost->perm_config, vhost->auth, vhost->auth_size, 1);
-			figure_auth_funcs(vhost, PREFIX_VHOST(vhost), &vhost->perm_config, vhost->eauth, vhost->eauth_size, 0);
+			figure_auth_funcs(vhost, PREFIX_VHOST(vhost), &vhost->perm_config,
+					  vhost->auth, vhost->auth_size, 1, ctx.is_worker);
+			figure_auth_funcs(vhost, PREFIX_VHOST(vhost), &vhost->perm_config,
+					  vhost->eauth, vhost->eauth_size, 0, ctx.is_worker);
 
-			figure_acct_funcs(vhost, PREFIX_VHOST(vhost), &vhost->perm_config, vhost->acct);
+			figure_acct_funcs(vhost, PREFIX_VHOST(vhost), &vhost->perm_config,
+					  vhost->acct, ctx.is_worker);
 
 			vhost->auth_init = 1;
 		}
@@ -1334,9 +1348,10 @@ static void parse_cfg_file(void *pool, const char *file, struct list_head *head,
 			vhost->urlfw = NULL;
 		}
 #endif
-		fprintf(stderr, NOTESTR"%ssetting '%s' as supplemental config option\n",
-			PREFIX_VHOST(vhost),
-			sup_config_name(vhost->perm_config.sup_config_type));
+		if (!ctx.is_worker)
+			fprintf(stderr, NOTESTR"%ssetting '%s' as supplemental config option\n",
+				PREFIX_VHOST(vhost),
+				sup_config_name(vhost->perm_config.sup_config_type));
 	}
 }
 
@@ -1580,6 +1595,8 @@ static void check_cfg(vhost_cfg_st *vhost, vhost_cfg_st *defvhost, unsigned sile
 #define OPT_NO_CHDIR 1
 static const struct option long_options[] = {
 	{"debug", 1, 0, 'd'},
+	{"log-stderr", 0, 0, 'e'},
+	{"syslog", 0, 0, 's'},
 	{"config", 1, 0, 'c'},
 	{"pid-file", 1, 0, 'p'},
 	{"test-config", 0, 0, 't'},
@@ -1594,7 +1611,7 @@ static const struct option long_options[] = {
 static
 void usage(void)
 {
-	fprintf(stderr, "ocserv - OpenConnect VPN server\n");
+	fprintf(stderr, PACKAGE" - "PACKAGE_NAME"\n");
 	fprintf(stderr, "Usage:  ocserv [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n\n");
 
 	fprintf(stderr, "   -f, --foreground           Do not fork into background\n");
@@ -1608,19 +1625,22 @@ void usage(void)
 	fprintf(stderr, "   -p, --pid-file=file        Specify pid file for the server\n");
 	fprintf(stderr, "   -v, --version              output version information and exit\n");
 	fprintf(stderr, "   -x, --traceable            Allow processes tracing\n");
-    fprintf(stderr, "               - use for debugging purposes only\n");
-	fprintf(stderr, "   -h, --help                 display extended usage information and exit\n\n");
+	fprintf(stderr, "               - use for debugging purposes only\n");
+	fprintf(stderr, "   -e, --log-stderr           Log to stderr\n");
+	fprintf(stderr, "   -s, --syslog               Log to syslog (default)\n");
+	fprintf(stderr, "   -h, --help                 Display extended usage information and exit\n\n");
 
-	fprintf(stderr, "OpenConnect VPN server (ocserv) is a VPN server compatible with the\n");
+	fprintf(stderr, PACKAGE_NAME" ("PACKAGE") is a VPN server compatible with the\n");
 	fprintf(stderr, "OpenConnect VPN client.  It follows the TLS and DTLS-based AnyConnect VPN\n");
 	fprintf(stderr, "protocol which is used by several CISCO routers.\n\n");
 
-	fprintf(stderr, "Please send bug reports to:  "PACKAGE_BUGREPORT"\n");
+	fprintf(stderr, "Please file bug reports at:  "PACKAGE_BUGREPORT"\n");
 }
 
 int cmd_parser (void *pool, int argc, char **argv, struct list_head *head, bool worker)
 {
 	unsigned test_only = 0;
+	unsigned debug_asked = 0;
 	int c;
 	vhost_cfg_st *vhost;
 
@@ -1643,11 +1663,19 @@ int cmd_parser (void *pool, int argc, char **argv, struct list_head *head, bool
 			strlcpy(cfg_file, optarg, sizeof(cfg_file));
 			break;
 		case 'd':
-			vhost->perm_config.debug = atoi(optarg);
+			vhost->perm_config.log_level = atoi(optarg);
+			global_log_prio = vhost->perm_config.log_level;
+			debug_asked = 1;
 			break;
 		case 't':
 			test_only = 1;
 			break;
+		case 'e':
+			vhost->perm_config.log_stderr = 1;
+			break;
+		case 's':
+			vhost->perm_config.syslog = 1;
+			break;
 		case OPT_NO_CHDIR:
 			vhost->perm_config.no_chdir = 1;
 			break;
@@ -1668,6 +1696,12 @@ int cmd_parser (void *pool, int argc, char **argv, struct list_head *head, bool
 		exit(EXIT_FAILURE);
 	}
 
+	if (vhost->perm_config.log_stderr == 0 && vhost->perm_config.syslog == 0) {
+		vhost->perm_config.syslog = 1; /* default if nothing specified*/
+		if (debug_asked)
+			vhost->perm_config.log_stderr = 1; /* compatible with previous behavior */
+	}
+
 	if (access(cfg_file, R_OK) != 0) {
 		fprintf(stderr, ERRSTR"cannot access config file: %s\n", cfg_file);
 		fprintf(stderr, "Usage: %s -c [config]\nUse %s --help for more information.\n", argv[0], argv[0]);
