@@ -20,6 +20,7 @@
  */
 
 #include <config.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -29,6 +30,8 @@
 #include <locale.h>
 #include <occtl/occtl.h>
 
+int syslog_open = 0;
+
 static int handle_reset_cmd(CONN_TYPE * conn, const char *arg, cmd_params_st *params);
 static int handle_help_cmd(CONN_TYPE * conn, const char *arg, cmd_params_st *params);
 static int handle_exit_cmd(CONN_TYPE * conn, const char *arg, cmd_params_st *params);
@@ -224,7 +227,7 @@ double data;
 
 	if (bytes > 1000 && bytes < 1000 * 1000) {
 		data = ((double) bytes) / 1000;
-		snprintf(output, output_size, "%.1f KB%s", data, suffix);
+		snprintf(output, output_size, "%.1f kB%s", data, suffix);
 	} else if (bytes >= 1000 * 1000 && bytes < 1000 * 1000 * 1000) {
 		data = ((double) bytes) / (1000 * 1000);
 		snprintf(output, output_size, "%.1f MB%s", data, suffix);
@@ -242,9 +245,9 @@ time2human(uint64_t microseconds, char* output, unsigned output_size)
 	if (microseconds < 1000) {
 		snprintf(output, output_size, "<1ms");
 	} else if (microseconds < 1000000) {
-		snprintf(output, output_size, "%ldms", microseconds / 1000);
+		snprintf(output, output_size, "%" PRIu64 "ms", microseconds / 1000);
 	} else {
-		snprintf(output, output_size, "%lds", microseconds / 1000000);
+		snprintf(output, output_size, "%" PRIu64 "s", microseconds / 1000000);
 	}
 }
 
