@@ -18,8 +18,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  */
-#ifndef ROUTE_ADD_H
-# define ROUTE_ADD_H
+#ifndef OC_ROUTE_ADD_H
+# define OC_ROUTE_ADD_H
 
 #include <vpn.h>
 #include <main.h>
