@@ -29,6 +29,7 @@
 #include "common/common.h"
 
 #include "vhost.h"
+#include "log.h"
 
 #define SESSION_STR "(session: %.6s)"
 #define MAX_GROUPS 128
@@ -86,7 +87,7 @@ typedef struct common_acct_info_st {
 typedef struct client_entry_st {
 	/* A unique session identifier used to distinguish sessions
 	 * prior to authentication. It is sent as cookie to the client
-	 * who re-uses it when it performs authentication in multiple
+	 * who reuses it when it performs authentication in multiple
 	 * sessions.
 	 */
 	uint8_t sid[SID_SIZE];
@@ -141,21 +142,6 @@ void del_client_entry(sec_mod_st *sec, client_entry_st * e);
 void expire_client_entry(sec_mod_st *sec, client_entry_st * e);
 void cleanup_client_entries(sec_mod_st *sec);
 
-#ifdef __GNUC__
-# define seclog(sec, prio, fmt, ...) { \
-	if (prio != LOG_DEBUG || GETPCONFIG(sec)->debug >= 3) { \
-		syslog(prio, "sec-mod: "fmt, ##__VA_ARGS__); \
-	}}
-#else
-# define seclog(sec,prio,...) { \
-	if (prio != LOG_DEBUG || GETPCONFIG(sec)->debug >= 3) { \
-		 syslog(prio, __VA_ARGS__); \
-	}}
-#endif
-
-void  seclog_hex(const struct sec_mod_st* sec, int priority,
-		const char *prefix, uint8_t* bin, unsigned bin_size, unsigned b64);
-
 void sec_auth_init(struct vhost_cfg_st *vhost);
 
 void handle_secm_list_cookies_reply(void *pool, int fd, sec_mod_st *sec);
