@@ -48,6 +48,7 @@
 #include <main.h>
 #include <ccan/list/list.h>
 #include "vhost.h"
+#include "log.h"
 
 #if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__DragonFly__)
 # include <net/if_var.h>
@@ -832,86 +833,3 @@ void reset_tun(struct proc_st* proc)
 	}
 }
 
-#if defined(__OpenBSD__) || defined(TUNSIFHEAD)
-# define TUN_AF_PREFIX 1
-#endif
-
-#ifdef TUN_AF_PREFIX
-ssize_t tun_write(int sockfd, const void *buf, size_t len)
-{
-	struct ip *iph = (void *)buf;
-	uint32_t head;
-	const uint8_t *data = buf;
-	static int complained = 0;
-	struct iovec iov[2];
-	int ret;
-
-	if (iph->ip_v == 6)
-		head = htonl(AF_INET6);
-	else if (iph->ip_v == 4)
-		head = htonl(AF_INET);
-	else {
-		if (!complained) {
-			complained = 1;
-			syslog(LOG_ERR, "tun_write: Unknown packet (len %d) received %02x %02x %02x %02x...\n",
-				(int)len, data[0], data[1], data[2], data[3]);
-		}
-		return -1;
-	}
-
-	iov[0].iov_base = &head;
-	iov[0].iov_len = sizeof(head);
-	iov[1].iov_base = (void*)buf;
-	iov[1].iov_len = len;
-
-	ret = writev(sockfd, iov, 2);
-	if (ret >= sizeof(uint32_t))
-		ret -= sizeof(uint32_t);
-	return ret;
-}
-
-ssize_t tun_read(int sockfd, void *buf, size_t len)
-{
-	uint32_t head;
-	struct iovec iov[2];
-	int ret;
-
-	iov[0].iov_base = &head;
-	iov[0].iov_len = sizeof(head);
-	iov[1].iov_base = buf;
-	iov[1].iov_len = len;
-
-	ret = readv(sockfd, iov, 2);
-	if (ret >= sizeof(uint32_t))
-		ret -= sizeof(uint32_t);
-	return ret;
-}
-
-#else
-ssize_t tun_write(int sockfd, const void *buf, size_t len)
-{
-	return force_write(sockfd, buf, len);
-}
-
-ssize_t tun_read(int sockfd, void *buf, size_t len)
-{
-	return read(sockfd, buf, len);
-}
-#endif
-
-#ifndef __FreeBSD__
-int tun_claim(int sockfd)
-{
-	return 0;
-}
-#else
-/*
- * FreeBSD has a mechanism by which a tunnel has a single controlling process,
- * and only that one process may close it.  When the controlling process closes
- * the tunnel, the state is torn down.
- */
-int tun_claim(int sockfd)
-{
-	return ioctl(sockfd, TUNSIFPID, 0);
-}
-#endif	/* !__FreeBSD__ */
