@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2018 Nikos Mavrogiannopoulos
+ * Copyright (C) 2013-2023 Nikos Mavrogiannopoulos
  * Copyright (C) 2015, 2016 Red Hat, Inc.
  *
  * This file is part of ocserv.
@@ -493,6 +493,7 @@ void ws_add_score_to_ip(worker_st *ws, unsigned points, unsigned final, unsigned
 	ban_ip_reply_msg__free_unpacked(reply, &pa);
 }
 
+static
 void send_stats_to_secmod(worker_st * ws, time_t now, unsigned discon_reason)
 {
 	CliStatsMsg msg = CLI_STATS_MSG__INIT;
@@ -753,11 +754,16 @@ static void peek_client_hello(struct worker_st *ws, gnutls_session_t session, in
 }
 #endif
 
-void check_camouflage_url(struct worker_st *ws)
+static void check_camouflage_url(struct worker_st *ws)
 {
 	if (WSCONFIG(ws)->camouflage_secret == NULL)
 		return;
 
+	if (ws->auth_state >= S_AUTH_COOKIE) {
+		ws->camouflage_check_passed = 1;
+		return;
+	}
+
 	char* url_camouflage_part = strchr(ws->req.url, '?');
 	if (url_camouflage_part
 		&& !strcmp(url_camouflage_part + 1, WSCONFIG(ws)->camouflage_secret))
@@ -1534,7 +1540,7 @@ static int dtls_mainloop(worker_st * ws, struct dtls_st * dtls, struct timespec
 			      ws->link_mtu, data_mtu);
 			ws->dtls_active_session++;
 			oclog(ws, LOG_DEBUG,
-				  "Maing DTLS session %d active", ws->dtls_active_session);
+				  "Main DTLS session %d active", ws->dtls_active_session);
 			session_info_send(ws);
 		}
 
@@ -1615,6 +1621,23 @@ static int tls_mainloop(struct worker_st *ws, struct timespec *tnow)
 	return ret;
 }
 
+/* Returns true if the data provided are not IP control messages
+ * (ICMP, IGMP). */
+static bool is_data(const uint8_t *data, size_t size)
+{
+	if (size > 20) {
+		uint8_t version = data[0] >> 4;
+		if (version == 0x04) {
+			if (data[9] == 0x01 || data[9] == 0x02) /* ICMP/IGMP */
+				return 0;
+		} else if (version == 0x06) {
+			if (data[9] == 0x3A || data[9] == 0x80)
+				return 0;
+		}
+	}
+	return 1;
+}
+
 static int tun_mainloop(struct worker_st *ws, struct timespec *tnow)
 {
 	int ret, l, e;
@@ -1643,7 +1666,6 @@ static int tun_mainloop(struct worker_st *ws, struct timespec *tnow)
 		return 0;
 	}
 
-
 	dtls_to_send.data = ws->buffer;
 	dtls_to_send.size = l;
 
@@ -1730,7 +1752,9 @@ static int tun_mainloop(struct worker_st *ws, struct timespec *tnow)
 			ret = cstp_send(ws, cstp_to_send.data, cstp_to_send.size + 8);
 			CSTP_FATAL_ERR_CMD(ws, ret, exit_worker_reason(ws, REASON_ERROR));
 		}
-		ws->last_nc_msg = tnow->tv_sec;
+
+		if (is_data(ws->buffer + 8, l)) /* do not account ICMP */
+			ws->last_nc_msg = tnow->tv_sec;
 	}
 
 	return 0;
@@ -1974,7 +1998,7 @@ static int connect_handler(worker_st * ws)
 	ret = cstp_puts(ws, "X-CSTP-Version: 1\r\n");
 	SEND_ERR(ret);
 
-	ret = cstp_puts(ws, "X-CSTP-Server-Name: "PACKAGE_STRING"\r\n");
+	ret = cstp_puts(ws, "X-CSTP-Server-Name: "PACKAGE_NAME"\r\n");
 	SEND_ERR(ret);
 
 	if (req->is_mobile) {
@@ -2049,7 +2073,7 @@ static int connect_handler(worker_st * ws)
 
 	/* Send IP addresses */
 	if (ws->vinfo.ipv4 && req->no_ipv4 == 0) {
-		oclog(ws, LOG_INFO, "sending IPv4 %s", ws->vinfo.ipv4);
+		oclog(ws, LOG_NOTICE, "sending IPv4 %s", ws->vinfo.ipv4);
 		ret =
 		    cstp_printf(ws, "X-CSTP-Address: %s\r\n",
 			       ws->vinfo.ipv4);
@@ -2064,7 +2088,7 @@ static int connect_handler(worker_st * ws)
 	}
 
 	if (ws->vinfo.ipv6 && req->no_ipv6 == 0 && ws->user_config->ipv6_prefix != 0) {
-		oclog(ws, LOG_INFO, "sending IPv6 %s/%u", ws->vinfo.ipv6, ws->user_config->ipv6_subnet_prefix);
+		oclog(ws, LOG_NOTICE, "sending IPv6 %s/%u", ws->vinfo.ipv6, ws->user_config->ipv6_subnet_prefix);
 		if (ws->full_ipv6 && ws->user_config->ipv6_subnet_prefix) {
 			ret =
 			    cstp_printf(ws,
@@ -2090,24 +2114,25 @@ static int connect_handler(worker_st * ws)
 		}
 	}
 
-	/* While anyconnect clients can handle the assignment
-	 * of an IPv6 address, they cannot handle routes or DNS
-	 * in IPv6. So we disable IPv6 after an IP is assigned. */
 	if (ws->full_ipv6 == 0) {
 		req->no_ipv6 = 1;
 		oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because IPv6 support was not requested.");
 	} else {
 		switch (req->user_agent_type) {
+		case AGENT_OPENCONNECT_V3:
+			req->no_ipv6 = 1;
+			oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because the agent is known not to support them.");
+			break;
 		case AGENT_OPENCONNECT:
 		case AGENT_ANYCONNECT:
 		case AGENT_OPENCONNECT_CLAVISTER:
 		case AGENT_ANYLINK:
+			oclog(ws, LOG_DEBUG, "Enabling IPv6 routes/DNS because the agent is known to support them.");
 			break;
-		case AGENT_OPENCONNECT_V3:
 		case AGENT_UNKNOWN:
 		default:
-			req->no_ipv6 = 1;
-			oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because the agent is not known.");
+			oclog(ws, LOG_NOTICE, "Enabling IPv6 routes/DNS although the agent is unknown.");
+			break;
 		}
 	}
 
@@ -2595,7 +2620,9 @@ static int parse_data(struct worker_st *ws, uint8_t *buf, size_t buf_size,
 			return -1;
 		}
 		ws->tun_bytes_in += plain_size;
-		ws->last_nc_msg = now;
+
+		if (is_data(plain, plain_size)) /* do not account ICMP */
+			ws->last_nc_msg = now;
 
 		break;
 	default:
